@@ -10,11 +10,11 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -25,6 +25,7 @@
 #ifndef XDX_GUI_MANUALDIALOG_H
 #define XDX_GUI_MANUALDIALOG_H
 
-void on_manual_activate (GtkMenuItem * menuitem, gpointer user_data);
+void on_manual_activate(GtkMenuItem *menuitem,
+                        gpointer     user_data);
 
 #endif /* XDX_GUI_MANUALDIALOG_H */
