@@ -10,11 +10,11 @@
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Library General Public License for more details.
+ * GNU General Public License for more details.
  *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ * You should have received a copy of the GNU General Public License along
+ * with this program; if not, write to the Free Software Foundation, Inc.,
+ * 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /*
@@ -25,16 +25,15 @@
 #ifndef XDX_TYPES_H
 #define XDX_TYPES_H
 
-enum
-{
-  FROM_COLUMN,
-  FREQ_COLUMN,
-  DX_COLUMN,
-  REM_COLUMN,
-  TIME_COLUMN,
-  INFO_COLUMN,
-  COUNTRY_COLUMN,
-  N_COLUMNS
+enum {
+    FROM_COLUMN,
+    FREQ_COLUMN,
+    DX_COLUMN,
+    REM_COLUMN,
+    TIME_COLUMN,
+    INFO_COLUMN,
+    COUNTRY_COLUMN,
+    N_COLUMNS
 };
 
 #endif /* XDX_TYPES_H */
